<!-- Copyright © SixtyFPS GmbH <info@slint.dev> ; SPDX-License-Identifier: MIT -->
## `GridBox`

A `GridBox` is a [`GridLayout`](../builtins/elements.md#gridlayout) where the spacing and padding values
depend on the style instead of defaulting to 0.
